Module prompt

Module prompt 

Structs

SynthesisExample
SynthesisResponse
Code + examples returned by the synthesis codegen LLM call.
SynthesisSpec
Specification for a stage the Composition Agent wants synthesized.

Functions

build_effect_inference_prompt
Build the effect inference prompt.
build_synthesis_prompt
Build the codegen prompt that asks the LLM to implement a synthesized stage.
build_system_prompt
Build the system prompt for the Composition Agent.
extract_effect_response
Parse an effect inference response from the LLM into an EffectSet.
extract_json
extract_synthesis_response
Try to parse a synthesis response (examples + implementation) from the LLM.
extract_synthesis_spec
Try to parse a synthesis request from the LLM response. Returns Some(SynthesisSpec) only when the JSON contains "action": "synthesize".