Module lagrange

Module lagrange 

Re-exports

pub use canonical::canonicalise;
pub use deprecation::resolve_deprecated_stages;
pub use deprecation::ChainEvent;
pub use deprecation::DeprecationReport;
pub use deprecation::DeprecationRewrite;
pub use deprecation::MAX_DEPRECATION_HOPS;
pub use resolver::resolve_pinning;
pub use resolver::ResolutionError;
pub use resolver::Rewrite;

Modules

canonical
Canonicalisation of composition graphs.
deprecation
Deprecation-chain resolver.
resolver
Pinning resolution pass.

Structs

CompositionGraph
A complete composition graph with metadata.

Enums

CompositionNode
A composition graph node. The core AST for Noether’s composition language.
Pinning
How a Stage reference resolves to a concrete stage in the store.
PrefixResolutionError
Errors raised by resolve_stage_prefixes when an ID in the graph cannot be uniquely resolved against the store.

Functions

collect_stage_ids
Collect all StageIds referenced in a composition node.
compute_composition_id
Compute a deterministic composition ID.
parse_graph
Parse a Lagrange JSON string into a CompositionGraph.
resolve_stage_prefixes
Walk a composition graph and replace any stage IDs that are unique prefixes — or human-authored names — of a real stage in the store with their full 64-character IDs.
resolve_stage_ref
Resolve a CompositionNode::Stage reference to a concrete stage in the store, respecting the node’s pinning.
serialize_graph
Serialize a CompositionGraph to pretty-printed JSON.