pub fn build_embedding_provider() -> (Box<dyn EmbeddingProvider>, &'static str)Expand description
Build the best available embedding provider based on env config.
Priority: Mistral native → Vertex AI → Mock.
pub fn build_embedding_provider() -> (Box<dyn EmbeddingProvider>, &'static str)Build the best available embedding provider based on env config.
Priority: Mistral native → Vertex AI → Mock.