Structs
- Synthesis
Example - Synthesis
Response - Code + examples returned by the synthesis codegen LLM call.
- Synthesis
Spec - Specification for a stage the Composition Agent wants synthesized.
Functions
- build_
effect_ inference_ prompt - Build the effect inference prompt.
- build_
synthesis_ prompt - Build the codegen prompt that asks the LLM to implement a synthesized stage.
- build_
system_ prompt - Build the system prompt for the Composition Agent.
- extract_
effect_ response - Parse an effect inference response from the LLM into an
EffectSet. - extract_
json - extract_
synthesis_ response - Try to parse a synthesis response (examples + implementation) from the LLM.
- extract_
synthesis_ spec - Try to parse a synthesis request from the LLM response.
Returns
Some(SynthesisSpec)only when the JSON contains"action": "synthesize".