Re-exports
pub use canonical::canonicalise;pub use resolver::resolve_pinning;pub use resolver::ResolutionError;pub use resolver::Rewrite;
Modules
Structs
- Composition
Graph - A complete composition graph with metadata.
Enums
- Composition
Node - A composition graph node. The core AST for Noether’s composition language.
- Pinning
- How a
Stagereference resolves to a concrete stage in the store. - Prefix
Resolution Error - Errors raised by
resolve_stage_prefixeswhen an ID in the graph cannot be uniquely resolved against the store.
Functions
- collect_
stage_ ids - Collect all StageIds referenced in a composition node.
- compute_
composition_ id - Compute a deterministic composition ID.
- parse_
graph - Parse a Lagrange JSON string into a CompositionGraph.
- resolve_
stage_ prefixes - Walk a composition graph and replace any stage IDs that are unique prefixes — or human-authored names — of a real stage in the store with their full 64-character IDs.
- resolve_
stage_ ref - Resolve a
CompositionNode::Stagereference to a concrete stage in the store, respecting the node’s pinning. - serialize_
graph - Serialize a CompositionGraph to pretty-printed JSON.