Skip to main content Module lagrange Copy item path Source CompositionGraph A complete composition graph with metadata. CompositionNode A composition graph node. The core AST for Noether’s composition language. PrefixResolutionError Errors raised by resolve_stage_prefixes when an ID in the graph cannot
be uniquely resolved against the store. collect_stage_ids Collect all StageIds referenced in a composition node. compute_composition_id Compute a deterministic composition ID (SHA-256 of canonical JSON). parse_graph Parse a Lagrange JSON string into a CompositionGraph. resolve_stage_prefixes Walk a composition graph and replace any stage IDs that are unique
prefixes — or human-authored names — of a real stage in the store with
their full 64-character IDs. serialize_graph Serialize a CompositionGraph to pretty-printed JSON.